@@ -2,6 +2,8 @@
 /* xemeraldia   ----- bitmaps.h */
 /*                              */
 
+#define char const char
+
 #include "./bitmaps/star.xbm"
 
 #include "./bitmaps/block1.xbm"
@@ -25,3 +27,5 @@
 #include "./bitmaps/crush2.xbm"
 #include "./bitmaps/crush3.xbm"
 #include "./bitmaps/crush4.xbm"
+
+#undef char
