@@ -5,9 +5,7 @@
 #include <time.h>
 #include <stdio.h>
 
-#define OBSTACLE  32
-#define EMPTY     0
-#define STAR      44
+#include "graphics.h"
 
 #define LUCKY_NUMBER  1
 
@@ -15,20 +13,14 @@
 #define MOVE_RIGHT    1
 #define MOVE_DOWN     1
 
-#define CRACKED       1
-#define DELETE        2
-#define NEW_CRACKED   5
-
-#define CHECKED       10
-
 #define CLOCKWIZE           1
 #define COUNTER_CLOCKWIZE  -1
 
 
 extern int   gameover_flag;
 extern long  sc, blocks, tmp_blocks, chain_step;
-extern int   paused;
-extern int   star_comes;
+extern gboolean   paused;
+extern gboolean   star_comes;
 extern int   movedown_counter;
 extern char *name, *programname;
 
@@ -38,15 +30,15 @@ extern int  iCrChk[4][2];
 
 struct Board
 {
-  int  blk;   /* blocks */
-  int  sub;   /* sub    */
-  int  chk;   /* check  */
+	cellstatus_t blk;   /* blocks */
+	cellsubstatus_t sub;   /* sub    */
+	cellstatus_t chk;   /* check  */
 };
 extern struct Board board[BOARD_WIDTH + 2][BOARD_HEIGHT + 1];
 
 struct DropItem {
-  int  col[3];
-  int  rot;
-  int  x, y;
+	cellstatus_t  col[3];
+	int  rot;
+	int  x, y;
 };
 extern struct DropItem  drop_i, next_i;
