@@ -1,6 +1,10 @@
 /*                              */
 /* xemeraldia   -----  usleep.c */
 /*                              */
+
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
  
 #ifdef SYSV
 #include <time.h>
@@ -8,8 +12,7 @@
 #include <sys/time.h>
 #endif
 
-void usleep (useconds)
-     unsigned useconds;
+void usleep(unsigned useconds)
 {
     struct timeval timeout;
 
